@@ -33,7 +33,7 @@ def get_people(html):
             links.append({'link': last.find('a').get('href'), 'work': 15})
         i = 1
         for link in links:
-            log.debug(f'\t{i}/{len(links)}')
+            log.debug(i + '/' + len(links))
             link_html = f.get_html(link['link'])
             link_soup = BeautifulSoup(link_html.text, 'html.parser')
             name = f.get_name(link_soup.find('h2', class_='senators_title').get_text().lower())
@@ -67,7 +67,7 @@ def parser():
         items = soup.find_all('div', class_='block__department')
         i = 1
         for item in items:
-            log.debug(f'Page {i}/{len(items)}')
+            log.debug('Page ' + i + '/' + len(items))
             link = item.find('a').get('href')
             link_html = f.get_html(link)
             box = get_people(link_html.text)
