@@ -73,7 +73,7 @@ def get_people(html):
         flag = True
         people = []
         for item in items:
-            log.debug(f'\t{count}/{len(items)}')
+            log.debug(count + '/' + len(items))
             if item.find('td'):
                 data = []
                 work = item.find_all('td')
@@ -109,7 +109,7 @@ def parser():
         people = []
         for j in range(0, len(links)+1):
             try:
-                log.debug(f'Page {j+1}/{len(links)}')
+                log.debug('Page ' + j + '/' + len(links))
                 html_committee = f.get_html(links[j])
                 people_list = get_people(html_committee.text)
                 if people_list != -1:
